@@ -14,7 +14,7 @@ def getOptionVal(options, key):
 def main():
     try:
         opts, args = getopt.gnu_getopt(sys.argv[1:], 'm:hvi:c:su:l:e:', [
-            'mode=', 'help', 'version', 'img_service=', 'change_token=', 'scan', 'des_dir=', 'url_encode=', 'language=', 'compress', 'debug=', 'engine='])
+            'mode=', 'help', 'version', 'img_service=', 'change_token=', 'scan', 'des_dir=', 'url_encode=', 'language=', 'compress', 'debug=', 'engine=', 'name='])
     except getopt.GetoptError as e:
         print("获取参数信息出错，错误提示：", e.msg)
         exit()
@@ -37,6 +37,10 @@ def main():
                     mainProcess.main()
                 elif mode == 'refresh':
                     mainProcess.main(True)
+                elif mode == 'backup_config':
+                    name = getOptionVal(opts, '--name')
+                    mainProcess.backupConfig(name)
+                    break
                 else:
                     print("错误的mode参数")
             elif argKey == '--img_service' or argKey == '-i':
